@@ -14,7 +14,7 @@ import importlib
 import inspect
 import itertools
 import shelve
-import sys, os
+import sys, os, re
 import warnings
 import weakref
 
@@ -106,9 +106,9 @@ def search_by_id(thingID):
         `sys.modules.values()` (which is potentially completely
         fucking enormous).
         
-        This function implements `search_for_name(…)` – q.v.
+        This function helps implement `search_for_name(…)` – q.v.
         the calling function code sub., and is also used in the
-        implementation of `determine_module(…)`, - also q.v.
+        implementation of `search_for_module(…)`, - also q.v.
         the calling function code sub.
         
         Caching courtesy the `functools.lru_cache(…)` decorator.
@@ -232,6 +232,9 @@ def determine_name(thing, name=None, try_repr=False):
     # up returning None:
     return search_for_name(thing)
 
+# Regexp for matching dashes in dotpaths:
+dash_re = re.compile("\-")
+
 # N.B. Items in the “replaceable_endings” tuple that
 # possibly contain other such items should appear
 # *before* the items that they contain, e.g.:
@@ -246,14 +249,16 @@ replaceable_endings  = tuple(f"{pre}{suf}" \
                                                   ending_suffixes))
 replaceable_endings += ending_suffixes
 
-def path_to_dotpath(path, relative_to=None):
+def path_to_dotpath(path, relative_to=None,
+                          convert_dashes=True):
     """ Convert a file path (e.g. “/yo/dogg/iheard/youlike.py”)
         to a dotpath (á la “yo.dogg.iheard.youlike”) in what I
         would call a “quick and dirty” fashion.
         
         Issues a BadDotpathWarning if the converted path contains
-        dashes – I don’t quite know what to do about something
-        like that besides warn, so erm. There you go.
+        dashes, and the “convert_datshes” flag is set to False
+        – I don’t quite know what to do about something like that
+        besides warn, so erm. There you go.
     """
     # Garbage in, garbage out:
     if path is None:
@@ -274,11 +279,15 @@ def path_to_dotpath(path, relative_to=None):
     while dotpath.startswith(QUALIFIER):
         dotpath = dotpath[1:]
     
-    # Warn before returning, if the converted path
-    # should contain dashes:
     if '-' in dotpath:
-        warnings.warn(f"Dotpath contains dashes: “{dotpath}”",
-                        BadDotpathWarning, stacklevel=2)
+        if convert_dashes:
+            # Substitute underscores for any dashes found:
+            dotpath = dash_re.subn('_', dotpath)[0]
+        else:
+            # Warn before returning, if the converted path
+            # should contain dashes:
+            warnings.warn(f"Dotpath contains dashes: “{dotpath}”",
+                            BadDotpathWarning, stacklevel=2)
     
     return dotpath
 
@@ -310,11 +319,12 @@ class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
     def __init_subclass__(cls, appname=None, **kwargs):
         if not appname:
             appname = determine_name(cls)
-        if appname in classes:
-            raise TypeError(f"appname already registered: {appname}")
-        appnames.add(appname)
-        classes[appname] = cls
-        super(Registry, cls).__init_subclass__(**kwargs) # type: ignore
+        else:
+            if appname in classes:
+                raise TypeError(f"appname already registered: {appname}")
+            appnames.add(appname)
+            classes[appname] = cls
+        super().__init_subclass__(**kwargs) # type: ignore
         cls.instances = weakref.WeakValueDictionary()
         cls.appname = clu.abstract.ValueDescriptor(appname)
     
@@ -860,7 +870,7 @@ class ExporterBase(collections.abc.MutableMapping,
                                                      'has_appname',
                                                      'for_appname',
                                                      'unregister'),
-                           super(ExporterBase, self).__dir__()))
+                           super().__dir__()))
 
 class Exporter(ExporterBase, basepath=BASEPATH, appname=APPNAME):
     
